# Copyright 1999-2004 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

inherit subversion eutils flag-o-matic multilib versionator toolchain-funcs

ECLASS=myth-svn
INHERITED="${INHERITED} ${ECLASS}"
IUSE="${IUSE} nls debug"

ESVN_FETCH_CMD="svn co"
ESVN_UPDATE_CMD="svn co"

EXPORT_FUNCTIONS src_unpack src_compile src_install

MYTHPLUGINS="mythbrowser mythdvd mythgallery mythgame mythmusic mythnews mythphone mythvideo mythweather mythweb"

atleast_0.18() {
	[[ $(get_version_component_range 1) > 0 || $(get_version_component_range 2) > 17 ]]
}

_MODULE=${PN/-svn/}

if atleast_0.18 && hasq ${_MODULE} ${MYTHPLUGINS} ; then
	ESVN_REPO_URI="http://cvs.mythtv.org/svn/trunk/mythplugins"
	ESVN_PROJECT=mythplugins
else
	ESVN_REPO_URI="http://cvs.mythtv.org/svn/trunk/mythtv"
        ESVN_PROJECT=${_MODULE/frontend/tv}
fi

ESVN_STORE_DIR="${DISTDIR}/svn-src"

S="${WORKDIR}/${_MODULE}"

myth-svn_src_unpack() {
	if atleast_0.18 && hasq ${_MODULE} ${MYTHPLUGINS} ; then
		pkg_pro="mythplugins.pro"
	elif [ "${_MODULE}" == "mythfrontend" ]; then
		pkg_pro="mythtv.pro"
	else
		pkg_pro="${_MODULE}.pro"
	fi

	subversion_src_unpack ; cd ${S}

	if use debug ; then
		FEATURES="${FEATURES} nostrip"
		sed \
			-e 's:#CONFIG += debug:CONFIG += debug:' \
			-e 's:CONFIG += release:#CONFIG += release:' \
			-i 'settings.pro' || die "Setting debug failed"
	fi

	sed \
		-e "s:PREFIX = /usr/local:PREFIX = /usr:" \
		-i 'settings.pro' || die "Settings PREFIX failed"

	if atleast_0.18 && hasq ${_MODULE} ${MYTHPLUGINS} ; then
		cd ${_MODULE}
	fi
																					if !  use nls ; then
		sed \
			-e "s:i18n::" \
			-i ${pkg_pro} || die "Disable i18n failed"
	fi

	setup_pro
}

myth-svn_src_compile() {
	if atleast_0.18 ; then
		if hasq ${_MODULE} ${MYTHPLUGINS} ; then
			for x in ${MYTHPLUGINS} ; do
				if [[ ${_MODULE} == ${x} ]] ; then
					myconf="${myconf} --enable-${x}"
				else
					myconf="${myconf} --disable-${x}"
				fi
			done
		fi

		econf ${myconf}
	fi

	qmake -o "Makefile" "${S}/${pkg_pro}"
	emake CC="$(tc-getCC)" CXX="$(tc-getCXX)" "${@}" || die
}

myth-svn_src_install() {
	if atleast_0.18 && hasq ${_MODULE} ${MYTHPLUGINS} ; then
		cd ${S}/${_MODULE}
	fi

	einstall INSTALL_ROOT="${D}"
	for doc in AUTHORS COPYING FAQ UPGRADING ChangeLog README; do
		test -e "${doc}" && dodoc ${doc}
	done
}
